generate event time under the delay-treatment effect and cured population setting given T>time0
Chen_2016_event_time_abovetime0(u, distribution, p, time0, a, b, mu, sd)the event time
a scalar with between 0 and 1
the distribution for the control arm, valid values of inputs include: exponential, weibull, log-normal, log-logistic
the proportion of cured population in the control arm
the observed ongoing survival time
the shape parameter in the Weibull or the log-logistic distribution
the scale parameter in the exponential, Weibull or the log-logistic distribution
the mean in the log-normal distribution
the standard deviation in the log-normal distribution
Chen, Tai-Tsang. "Predicting analysis times in randomized clinical trials with cancer immunotherapy." BMC medical research methodology 16.1 (2016): 1-10.