generate event time under the delay-treatment effect and cured population setting
Chen_2016_event_time_piecewise_exp_abovetime0(
u,
p,
time0 = 0,
piecewiseSurvivalTime = 0,
piecewisehazard
)the event time
a scalar with between 0 and 1, which is the conditional survival probability at the event time.
the proportion of cured population in the control arm
the observed ongoing survival time
A vector that specifies the time intervals for the piecewise exponential survival distribution. Must start with 0, e.g., c(0, 60) breaks the time axis into 2 event intervals: [0, 60) and [60, Inf). By default, it is set to 0.
A vector that specifies the hazard rate in intervals for the piecewise exponential survival distribution.
Chen, Tai-Tsang. "Predicting analysis times in randomized clinical trials with cancer immunotherapy." BMC medical research methodology 16.1 (2016): 1-10.