Provide log-likelihood function for log-logistic distribution with cured population
loglik_Chen_log_logistic(par, df)The negative value of the log-likelihood function given parameter
par and the dataset df
a vector with three elements, where the first element denotes the logistic of the proportion of the cured population, and the second element and the third element denote the log of shape and the log of the scale parameter of the log-logistic distribution.
The subject-level event data, including time
and event.
Chen, Tai-Tsang. "Predicting analysis times in randomized clinical trials with cancer immunotherapy." BMC medical research methodology 16.1 (2016): 1-10.